( cd usr/lib/setup ; rm -rf pkgtool )
( cd usr/lib/setup ; ln -sf cpkgtool pkgtool )
( cd usr/lib/setup ; rm -rf setup )
( cd usr/lib/setup ; ln -sf hdsetup setup )
( cd sbin ; rm -rf setup )
( cd sbin ; ln -sf /usr/lib/setup/hdsetup setup )
( cd sbin ; rm -rf pkgtool )
( cd sbin ; ln -sf /usr/lib/setup/cpkgtool pkgtool )
( cd usr/lib/terminfo/a ; rm -rf ansiterm )
( cd usr/lib/terminfo/a ; ln -sf ansi ansiterm )
( cd usr/lib/terminfo/c ; rm -rf console )
( cd usr/lib/terminfo/c ; ln -sf ../l/linux console )
( cd usr/lib/terminfo/c ; rm -rf con132x43 )
( cd usr/lib/terminfo/c ; ln -sf console con132x43 )
( cd usr/lib/terminfo/c ; rm -rf con80x25 )
( cd usr/lib/terminfo/c ; ln -sf console con80x25 )
( cd usr/lib/terminfo/c ; rm -rf con80x28 )
( cd usr/lib/terminfo/c ; ln -sf console con80x28 )
( cd usr/lib/terminfo/c ; rm -rf con80x30 )
( cd usr/lib/terminfo/c ; ln -sf console con80x30 )
( cd usr/lib/terminfo/c ; rm -rf con80x43 )
( cd usr/lib/terminfo/c ; ln -sf console con80x43 )
( cd usr/lib/terminfo/c ; rm -rf con80x60 )
( cd usr/lib/terminfo/c ; ln -sf console con80x60 )
( cd usr/lib/terminfo/c ; rm -rf con132x25 )
( cd usr/lib/terminfo/c ; ln -sf console con132x25 )
( cd usr/lib/terminfo/c ; rm -rf con132x30 )
( cd usr/lib/terminfo/c ; ln -sf console con132x30 )
( cd usr/lib/terminfo/c ; rm -rf con132x60 )
( cd usr/lib/terminfo/c ; ln -sf console con132x60 )
( cd usr/lib/terminfo/c ; rm -rf con80x50 )
( cd usr/lib/terminfo/c ; ln -sf console con80x50 )
( cd usr/lib/terminfo/h ; rm -rf hp70092a )
( cd usr/lib/terminfo/h ; ln -sf hp70092 hp70092a )
( cd usr/lib/terminfo/h ; rm -rf hp70092A )
( cd usr/lib/terminfo/h ; ln -sf hp70092 hp70092A )
( cd usr/lib/terminfo/p ; rm -rf pc3 )
( cd usr/lib/terminfo/p ; ln -sf pc pc3 )
( cd usr/lib/terminfo/p ; rm -rf pccons )
( cd usr/lib/terminfo/p ; ln -sf pc pccons )
( cd usr/lib/terminfo/v ; rm -rf vt100-am )
( cd usr/lib/terminfo/v ; ln -sf vt100 vt100-am )
( cd usr/lib/terminfo/v ; rm -rf vt100am )
( cd usr/lib/terminfo/v ; ln -sf vt100 vt100am )
( cd usr/lib/terminfo/v ; rm -rf vt220 )
( cd usr/lib/terminfo/v ; ln -sf vt200 vt220 )
( cd usr/lib/terminfo/v ; rm -rf vt200-js )
( cd usr/lib/terminfo/v ; ln -sf vt200 vt200-js )
( cd usr/lib/terminfo/v ; rm -rf vt220-js )
( cd usr/lib/terminfo/v ; ln -sf vt200 vt220-js )
( cd usr/lib/terminfo/v ; rm -rf vt320 )
( cd usr/lib/terminfo/v ; ln -sf vt300 vt320 )
( cd usr/lib/terminfo/x ; rm -rf xterm )
( cd usr/lib/terminfo/x ; ln -sf ../v/vs100 xterm )
( cd usr/lib/terminfo/x ; rm -rf xterm-vi )
( cd usr/lib/terminfo/x ; ln -sf xterm-ic xterm-vi )
( cd usr/lib/terminfo/x ; rm -rf xterms )
( cd usr/lib/terminfo/x ; ln -sf ../v/vs100s xterms )
( cd usr/lib/terminfo/7 ; rm -rf 70092 )
( cd usr/lib/terminfo/7 ; ln -sf ../h/hp70092 70092 )
( cd usr/lib/terminfo/7 ; rm -rf 70092a )
( cd usr/lib/terminfo/7 ; ln -sf ../h/hp70092 70092a )
( cd usr/lib/terminfo/7 ; rm -rf 70092A )
( cd usr/lib/terminfo/7 ; ln -sf ../h/hp70092 70092A )
